/*
 * (c) Bernd Müller & Harald Wehr, www.jpainfo.de
 */
package de.jpainfo.model;

import java.math.BigDecimal;

import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;

import static de.jpainfo.model.Buchungsart.*;

@Entity
@Inheritance(strategy = InheritanceType.TABLE_PER_CLASS)
public abstract class Konto {

	@Id @GeneratedValue(strategy = GenerationType.SEQUENCE)
	//@Id @GeneratedValue(generator = "KtoSeq", strategy = GenerationType.SEQUENCE)
	//@SequenceGenerator(name = "KtoSeq", sequenceName = "KTO_SEQ", allocationSize = 100, initialValue = 100000)
	private Integer kontonummer;
	@Column(precision = 10, scale = 2)
	private BigDecimal kontostand;
	
	@ManyToOne(optional = false)
	@JoinColumn(name = "kunde", nullable = false)
	private Kunde kunde;
	
	@OneToMany(mappedBy = "konto", cascade = CascadeType.ALL)
	private Set<Buchung> buchungen;
	

	public Konto() {
		kontostand = BigDecimal.ZERO.setScale(2);
		buchungen = new HashSet<Buchung>();
	}

	public void addBuchung(Buchung buchung) {
		buchung.setKonto(this);
		buchungen.add(buchung);
		if (buchung.getBuchungsart() == HABEN) {
			kontostand = kontostand.add(buchung.getBetrag());
		} else {
			kontostand = kontostand.subtract(buchung.getBetrag());
		}
	}
	
	
	// Getter und Setter
	public Integer getKontonummer() {
		return kontonummer;
	}

	
	public BigDecimal getKontostand() {
		return kontostand;
	}
	public void setKontostand(BigDecimal kontostand) {
		this.kontostand = kontostand;
	}


	public Kunde getKunde() {
		return kunde;
	}
	public void setKunde(Kunde kunde) {
		this.kunde = kunde;
	}


	public Set<Buchung> getBuchungen() {
		return buchungen;
	}
	public void setBuchungen(Set<Buchung> buchungen) {
		this.buchungen = buchungen;
	}

	
}
