/*
 * (c) Bernd Müller & Harald Wehr, www.jpainfo.de
 */
package de.jpainfo.model;

import java.text.DateFormat;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

@Entity
public class Kunde {
	
	private static final DateFormat format = new SimpleDateFormat("dd.MM.yyyy");
	
	@Id @GeneratedValue 
	private Integer id;
	private String vorname;
	private String nachname;
	@Temporal(TemporalType.DATE)
	private Date geburtsdatum;
	private Anrede anrede;
	

	@OneToMany(mappedBy = "kunde", cascade = CascadeType.ALL)
	private Set<Konto> konten;
	
	
	public Kunde() {
		konten = new HashSet<Konto>();
	}
	
	
	public Kunde(String vorname, String nachname, String geburtsdatum, Anrede anrede) {
		this();
		this.vorname = vorname;
		this.nachname = nachname;
		this.anrede = anrede;
		try {
			this.geburtsdatum = format.parse(geburtsdatum);
		} catch (ParseException e) {
			throw new IllegalArgumentException("Falsches Datumsformat");
		}
	}
	
	
	public void addKonto(Konto konto) {
		konto.setKunde(this);
		konten.add(konto);
	}
	

	
	// Getter und Setter
	public Integer getId() {
		return id;
	}
	
	
	public String getVorname() {
		return vorname;
	}
	public void setVorname(String vorname) {
		this.vorname = vorname;
	}

	
	public String getNachname() {
		return nachname;
	}
	public void setNachname(String nachname) {
		this.nachname = nachname;
	}

	
	public Date getGeburtsdatum() {
		return geburtsdatum;
	}
	public void setGeburtsdatum(Date geburtsdatum) {
		this.geburtsdatum = geburtsdatum;
	}

	
	public Anrede getAnrede() {
		return anrede;
	}
	public void setAnrede(Anrede anrede) {
		this.anrede = anrede;
	}


	public Set<Konto> getKonten() {
		return konten;
	}
	
	
}
